pub struct RemoteServerClient<R: ReadWrite> { /* private fields */ }Expand description
Client for communicating with iOS remote server protocol
Manages multiple communication channels and handles message serialization/deserialization. Each channel operates independently and maintains its own message queue.
Implementations
Sourceimpl<R: ReadWrite> RemoteServerClient<R>
impl<R: ReadWrite> RemoteServerClient<R>
Sourcepub fn root_channel<'c>(&'c mut self) -> Channel<'c, R>
pub fn root_channel<'c>(&'c mut self) -> Channel<'c, R>
Returns a handle to the root channel (channel 0)
Sourcepub async fn make_channel<'c>(
&'c mut self,
identifier: impl Into<String>,
) -> Result<Channel<'c, R>, IdeviceError>
pub async fn make_channel<'c>( &'c mut self, identifier: impl Into<String>, ) -> Result<Channel<'c, R>, IdeviceError>
Creates a new channel with the given identifier
Arguments
identifier- String identifier for the new channel
Returns
Ok(Channel)- Handle to the new channelErr(IdeviceError)- If channel creation fails
Errors
- `IdeviceError::UnexpectedResponse(“unexpected response”.into()) if server responds with unexpected data
- Other IO or serialization errors
Sourcepub async fn call_method(
&mut self,
channel: i32,
data: Option<impl Into<Value>>,
args: Option<Vec<AuxValue>>,
expect_reply: bool,
) -> Result<(), IdeviceError>
pub async fn call_method( &mut self, channel: i32, data: Option<impl Into<Value>>, args: Option<Vec<AuxValue>>, expect_reply: bool, ) -> Result<(), IdeviceError>
Calls a method on the specified channel
Arguments
channel- Channel number to call method ondata- Optional method data (plist value)args- Optional arguments for the methodexpect_reply- Whether to expect a response
Returns
Ok(())- If method was successfully calledErr(IdeviceError)- If call failed
Errors
IO or serialization errors
Sourcepub async fn read_message(
&mut self,
channel: i32,
) -> Result<Message, IdeviceError>
pub async fn read_message( &mut self, channel: i32, ) -> Result<Message, IdeviceError>
Reads the next message from the specified channel
Checks cached messages first, then reads from transport if needed.
Arguments
channel- Channel number to read from
Returns
Ok(Message)- The received messageErr(IdeviceError)- If read failed
Errors
IdeviceError::UnknownChannelif channel doesn’t exist- Other IO or deserialization errors
Sourceimpl RemoteServerClient<Box<dyn ReadWrite>>
impl RemoteServerClient<Box<dyn ReadWrite>>